@@ -11,11 +11,12 @@
 -- Convert from Feeds to XML.
 --
 --------------------------------------------------------------------
-
-
 module Text.Feed.Export
-       ( Text.Feed.Export.xmlFeed  -- :: Feed -> XML.Element
-       ) where
+  ( Text.Feed.Export.xmlFeed -- :: Feed -> XML.Element
+  ) where
+
+import Prelude ()
+import Prelude.Compat ()
 
 import Text.Feed.Types
 
@@ -23,14 +24,14 @@ import Text.Atom.Feed.Export as Atom
 import Text.RSS.Export as RSS
 import Text.RSS1.Export as RSS1
 
-import Text.XML.Light as XML
+import Data.XML.Types as XML
 
 -- | 'xmlFeed f' serializes a @Feed@ document into a conforming
 -- XML toplevel element.
 xmlFeed :: Feed -> XML.Element
 xmlFeed fe =
   case fe of
-   AtomFeed f -> Atom.xmlFeed f
-   RSSFeed  f -> RSS.xmlRSS f
-   RSS1Feed f -> RSS1.xmlFeed f
-   XMLFeed e  -> e -- that was easy!
+    AtomFeed f -> Atom.xmlFeed f
+    RSSFeed f -> RSS.xmlRSS f
+    RSS1Feed f -> RSS1.xmlFeed f
+    XMLFeed e -> e -- that was easy!
