@@ -1,15 +1,15 @@
-module Main (main) where
+module Main
+  ( main
+  ) where
+
+import Prelude ()
+import Prelude.Compat
 
 import Example (exampleTests)
 import Test.Framework (defaultMain)
-import Text.RSS.Tests (rssTests)
 import Text.Atom.Tests (atomTests)
 import Text.Feed.Util.Tests (feedUtilTests)
+import Text.RSS.Tests (rssTests)
 
 main :: IO ()
-main = defaultMain
-  [ rssTests
-  , atomTests
-  , feedUtilTests
-  , exampleTests
-  ]
+main = defaultMain [rssTests, atomTests, feedUtilTests, exampleTests]
